@@ -32,7 +32,7 @@ CH = "CH"  # Character
 DE = "DE"  # Decimal
 DT = "DT"  # Date ddmmyy
 HX = "HX"  # Hexadecimal
-IN = "NU"  # Integer
+IN = "IN"  # Integer
 LA = "LA"  # Latitude value ddmm.mmmmm
 LN = "LN"  # Longitude value dddmm.mmmmm
 ST = "ST"  # String
